import React, {Component} from "react";
import Loading from "./Loading";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { faCancel, faSave, faEdit } from "@fortawesome/free-solid-svg-icons";
import { Tooltip } from "react-tooltip";
export default class EditableTextDisplay extends Component {

    constructor(props) {
        super(props)

        this.state = {
            editValue: '',
            loading: false,
            edit: false
        }
    }

    edit = () => {
        this.setState({
            editValue: this.props.defaultValue,
            edit: true
        })
    }

    handleChange = (event) => {
        this.setState({
            editValue: event.target.value
        })
    }

    cancel = () => {
        this.setState({
            editValue: '',
            edit: false
        })
    }

    propagateChange = () => {
        this.props.callback(this.state.editValue, this.props.label);

        this.setState({
            edit: false
        })
    }

    render () {
        return (
            <div>
                {
                    (this.state.loading)
                    ? <Loading />
                    : (this.state.edit)
                        ? <div className="flex flex-row items-center">
                            <input className="ml-2 border px-2" type={this.props.fieldType} value={this.state.editValue} onChange={this.handleChange} />
                            <div id={`${this.props.label}Cancel`} className="ml-2" onClick={this.cancel}><FontAwesomeIcon icon={faCancel} /></div>
                            <div id={`${this.props.label}Save`} className="ml-2" onClick={this.propagateChange}><FontAwesomeIcon icon={faSave} /></div>
                            <Tooltip anchorSelect={`#${this.props.label}Save`} place="bottom">
                                Save {this.props.label.toUpperCase()}
                            </Tooltip>
                            <Tooltip anchorSelect={`#${this.props.label}Cancel`} place="bottom">
                                Cancel {this.props.label.toUpperCase()} Edit
                            </Tooltip>
                        </div>
                        : <div className="flex flex-row ml-2">
                            <div>{this.props.defaultValue}</div>
                            <div id={`${this.props.label}Edit`} className="ml-2" onClick={this.edit}><FontAwesomeIcon icon={faEdit} /></div>
                            <Tooltip anchorSelect={`#${this.props.label}Edit`} place="bottom">
                                Edit {this.props.label.toUpperCase()}
                            </Tooltip>
                        </div>
                    
                }
            </div>
        )
    }
}